/**
 *  Copyright 2006 Philip Jacob Licensed under the Apache License, 
 *  Version 2.0 (the "License"); you may not use this file except in compliance with 
 *  the License. You may obtain a copy of the License at 
 *  http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or 
 *  agreed to in writing, software distributed under the License is distributed on an 
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and limitations 
 *  under the License.
 *  
 */

package com.whirlycott.s3cdnfilter;

import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;

public interface S3CDNAction {

	/**
	 * This should perform a test as quickly as possible to see if a push to S3
	 * is required.
	 * 
	 * @param bucket
	 * @param key
	 * @return
	 */
	public boolean needsPushed(final ServletRequest req, final ServletResponse res);

	/**
	 * Implementations of this method should create an object that can be used
	 * to push the data to S3.
	 * 
	 * @param req
	 * @param res
	 * @return
	 */
	public S3CDNObject prepare(final ServletRequest req, final ServletResponse res);

	/**
	 * Once the upload to S3 has occurred, it's almost certain that you'll need
	 * to rewrite some local URL or perform some kind of an action so your
	 * webapp knows where to get the content. You should do that in this method.
	 * 
	 * @param obj
	 */
	public void commit(final S3CDNObject obj);

}
